@@ -137,8 +137,10 @@ checkDataTypeInput <- function(legacy, data.type){
             "Masked Copy Number Segment",
             "Isoform Expression Quantification",
             "miRNA Expression Quantification",
+            "Gene Level Copy Number",
             "Biospecimen Supplement",
             "Gene Level Copy Number Scores",
+            "Protein Expression Quantification",
             "Clinical Supplement",
             "Masked Somatic Mutation",
             "Slide Image")
