@@ -44,6 +44,7 @@
 #' @importFrom data.table setcolorder setnames
 #' @importFrom GenomicRanges GRanges
 #' @importFrom IRanges IRanges
+#' @importFrom purrr map_chr
 GDCprepare <- function(
   query,
   save = FALSE,
@@ -69,12 +70,21 @@ GDCprepare <- function(
   isServeOK()
   if(missing(query)) stop("Please set query parameter")
 
-  test.duplicated.cases <- (any(duplicated(query$results[[1]]$cases)) &
-                              !(query$data.type %in% c("Clinical data",
-                                                       "Protein expression quantification",
-                                                       "Raw intensities",
-                                                       "Clinical Supplement",
-                                                       "Biospecimen Supplement")))
+  test.duplicated.cases <-
+    (
+      any(
+        duplicated(query$results[[1]]$cases)) & # any duplicated
+        !(query$data.type %in% c(
+          "Clinical data",
+          "Protein expression quantification",
+          "Raw intensities",
+          "Clinical Supplement",
+          "Masked Somatic Mutation",
+          "Biospecimen Supplement")
+        )
+    )
+
+  "Aliquot Ensemble Somatic Variant Merging and Masking"
 
   if(test.duplicated.cases) {
     dup <- query$results[[1]]$cases[duplicated(query$results[[1]]$cases)]
@@ -119,21 +129,28 @@ GDCprepare <- function(
 
       }
     } else {
-      stop(paste0("I couldn't find all the files from the query. ",
-                  "Please check if the directory parameter is right or `GDCdownload` downloaded the samples."))
+      stop(
+        paste0("I couldn't find all the files from the query. ",
+               "Please check if the directory parameter is right or `GDCdownload` downloaded the samples.")
+      )
     }
   }
 
   cases <- ifelse(grepl("TCGA|TARGET",query$results[[1]]$project %>% unlist()),query$results[[1]]$cases,query$results[[1]]$sample.submitter_id)
+
   if (grepl("Transcriptome Profiling", query$data.category, ignore.case = TRUE)){
-    data <- readTranscriptomeProfiling(files = files,
-                                       data.type = ifelse(!is.na(query$data.type),  as.character(query$data.type),  unique(query$results[[1]]$data_type)),
-                                       workflow.type = unique(query$results[[1]]$analysis_workflow_type),
-                                       cases = cases,
-                                       summarizedExperiment)
+    data <- readTranscriptomeProfiling(
+      files = files,
+      data.type = ifelse(!is.na(query$data.type),  as.character(query$data.type),  unique(query$results[[1]]$data_type)),
+      workflow.type = unique(query$results[[1]]$analysis_workflow_type),
+      cases = cases,
+      summarizedExperiment
+    )
   } else if(grepl("Copy Number Variation",query$data.category,ignore.case = TRUE)) {
     if (unique(query$results[[1]]$data_type) == "Gene Level Copy Number Scores") {
       data <- readGISTIC(files, query$results[[1]]$cases)
+    } else if (unique(query$results[[1]]$data_type) == "Gene Level Copy Number") {
+      data <- readGeneLevelCopyNumber(files, query$results[[1]]$cases,summarizedExperiment = summarizedExperiment)
     } else {
       data <- readCopyNumberVariation(files, query$results[[1]]$cases)
     }
@@ -142,10 +159,13 @@ GDCprepare <- function(
   }  else if (grepl("Raw intensities",query$data.type, ignore.case = TRUE)) {
     # preparing IDAT files
     data <- readIDATDNAmethylation(files, barcode = cases, summarizedExperiment, unique(query$platform), query$legacy)
+  }  else if (grepl("Proteome Profiling",query$data.category,ignore.case = TRUE)) {
+    data <- readProteomeProfiling(files, cases = cases)
   }  else if (grepl("Protein expression",query$data.category,ignore.case = TRUE)) {
     data <- readProteinExpression(files, cases = cases)
+    if(summarizedExperiment) message("SummarizedExperiment not implemented, if you need samples metadata use the function TCGAbiolinks:::colDataPrepare")
   }  else if (grepl("Simple Nucleotide Variation",query$data.category,ignore.case = TRUE)) {
-    if(grepl("Masked Somatic Mutation",query$results[[1]]$data_type,ignore.case = TRUE) | source == "legacy")
+    if(grepl("Masked Somatic Mutation",query$results[[1]]$data_type[1],ignore.case = TRUE) | source == "legacy")
       suppressWarnings(data <- readSimpleNucleotideVariationMaf(files))
   }  else if (grepl("Clinical|Biospecimen", query$data.category, ignore.case = TRUE)){
     data <- readClinical(files, query$data.type, cases = cases)
@@ -309,9 +329,11 @@ readExonQuantification <- function (files, cases, summarizedExperiment = TRUE){
       return(x)
     })
     rowRanges <- makeGRangesFromDataFrame(df)
-    rse <- SummarizedExperiment(assays=assays,
-                                rowRanges=rowRanges,
-                                colData=colData)
+    rse <- SummarizedExperiment(
+      assays = assays,
+      rowRanges = rowRanges,
+      colData = colData
+    )
     return(rse)
   }
   return(df)
@@ -401,8 +423,6 @@ readSimpleNucleotideVariationMaf <- function(files){
   return(ret)
 }
 
-
-#' @importFrom purrr reduce
 readGeneExpressionQuantification <- function(
   files,
   cases,
@@ -432,19 +452,24 @@ readGeneExpressionQuantification <- function(
       if(!missing(cases)) {
         assay.list <<- gsub(" |\\(|\\)|\\/","_",colnames(data)[2:ncol(data)])
         # We will use this because there might be more than one col for each samples
-        setnames(data,colnames(data)[2:ncol(data)],
-                 paste0(gsub(" |\\(|\\)|\\/","_",colnames(data)[2:ncol(data)]),"_",cases[i]))
+        setnames(
+          data,
+          colnames(data)[2:ncol(data)],
+          paste0(gsub(" |\\(|\\)|\\/","_",colnames(data)[2:ncol(data)]),"_",cases[i])
+        )
       }
       data
     },.progress = "time",cases = cases)
 
   print.header(paste0("Merging ", length(files)," files"),"subsection")
-  merging.col <- colnames(ret[[1]])[1]
-  df <- purrr::reduce(
-    ret,
-    dplyr::full_join,,
-    by = merging.col
-  )
+
+  # Just check if the data is in the same order, since we will not merge
+  # the data frames to save memory
+  stopifnot(all(unlist(ret %>% map(function(y){all(y[,1] ==  ret[[1]][,1])}) )))
+
+  # need to check if it works in all cases
+  df <- ret %>% map( ~ (.x %>% dplyr::select(-1))) %>% bind_cols()
+  df <- bind_cols(ret[[1]][,1],df)
 
   if (summarizedExperiment) {
     df <- makeSEfromGeneExpressionQuantification(df, assay.list, genome = genome)
@@ -538,53 +563,40 @@ makeSEfromGeneExpressionQuantification <- function(
 
 #' @importFrom downloader download
 #' @importFrom S4Vectors DataFrame
-makeSEFromDNAMethylationMatrix <- function(betas, genome = "hg38", met.platform = "450K") {
+makeSEFromDNAMethylationMatrix <- function(
+  betas,
+  genome = "hg38",
+  met.platform = "450K"
+) {
   message("=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-")
   message("Creating a SummarizedExperiment from DNA methylation input")
 
   # Instead of looking on the size, it is better to set it as a argument as the annotation is different
-  annotation <-   getInfiniumAnnotation(met.platform, genome)
+  annotation <-   getMetPlatInfo(platform = met.platform, genome = genome)
 
-  rowRanges <- annotation[names(annotation) %in% rownames(betas),,drop=FALSE]
+  rowRanges <- annotation[names(annotation) %in% rownames(betas),,drop = FALSE]
 
   colData <-  DataFrame(samples = colnames(betas))
   betas <- betas[rownames(betas) %in% names(rowRanges),,drop = FALSE]
   betas <- betas[names(rowRanges),,drop = FALSE]
   assay <- data.matrix(betas)
-  betas <- SummarizedExperiment(assays=assay,
-                                rowRanges=rowRanges,
-                                colData=colData)
+  betas <- SummarizedExperiment(
+    assays = assay,
+    rowRanges = rowRanges,
+    colData = colData
+  )
   return(betas)
 }
 
-
-getInfiniumAnnotation <- function(platform, genome){
-  base <- "http://zwdzwd.io/InfiniumAnnotation/current/"
-  path <- file.path(base,platform,paste(platform,"hg19.manifest.rds", sep ="."))
-  if (grepl("hg38", genome)) path <- gsub("hg19","hg38",path)
-  if(platform == "EPIC") {
-    annotation <- paste0(base,"EPIC/EPIC.hg19.manifest.rds")
-  } else if(platform == "450K") {
-    annotation <- paste0(base,"hm450/hm450.hg19.manifest.rds")
-  } else {
-    annotation <- paste0(base,"hm27/hm27.hg19.manifest.rds")
-  }
-  if(grepl("hg38", genome)) annotation <- gsub("hg19","hg38",annotation)
-  if(!file.exists(basename(annotation))) {
-    if(Sys.info()["sysname"] == "Windows") mode <- "wb" else  mode <- "w"
-    downloader::download(annotation, basename(annotation), mode = mode)
-  }
-  readRDS(basename(annotation))
-}
-
-
-makeSEfromDNAmethylation <- function(df, probeInfo=NULL){
+makeSEfromDNAmethylation <- function(df, probeInfo = NULL){
   if(is.null(probeInfo)) {
-    rowRanges <- GRanges(seqnames = paste0("chr", df$Chromosome),
-                         ranges = IRanges(start = df$Genomic_Coordinate,
-                                          end = df$Genomic_Coordinate),
-                         probeID = df$Composite.Element.REF,
-                         Gene_Symbol = df$Gene_Symbol)
+    rowRanges <- GRanges(
+      seqnames = paste0("chr", df$Chromosome),
+      ranges = IRanges(start = df$Genomic_Coordinate,
+                       end = df$Genomic_Coordinate),
+      probeID = df$Composite.Element.REF,
+      Gene_Symbol = df$Gene_Symbol
+    )
 
     names(rowRanges) <- as.character(df$Composite.Element.REF)
     colData <-  colDataPrepare(colnames(df)[5:ncol(df)])
@@ -643,7 +655,11 @@ readIDATDNAmethylation <- function(
     met.platform <- "EPIC"
     if (grepl("450",platform)) met.platform <- "450K"
     if (grepl("27",platform)) met.platform <- "27K"
-    betas <- makeSEFromDNAMethylationMatrix(betas,genome = ifelse(legacy,"hg19","hg38"),met.platform = met.platform)
+    betas <- makeSEFromDNAMethylationMatrix(
+      betas = betas,
+      genome = ifelse(legacy,"hg19","hg38"),
+      met.platform = met.platform
+    )
     colData(betas) <- DataFrame(colDataPrepare(colnames(betas)))
   }
   return(betas)
@@ -663,7 +679,8 @@ readDNAmethylation <- function(files, cases, summarizedExperiment = TRUE, platfo
     pb <- txtProgressBar(min = 0, max = length(files), style = 3)
     for (i in seq_along(files)) {
       data <- fread(
-        files[i], header = TRUE,
+        files[i],
+        header = TRUE,
         sep = "\t",
         stringsAsFactors = FALSE,
         skip = 1,
@@ -715,11 +732,25 @@ readDNAmethylation <- function(files, cases, summarizedExperiment = TRUE, platfo
 
 
     print.header(paste0("Merging ", length(files)," files"),"subsection")
-    df <- purrr::reduce(x, dplyr::left_join)
+
+    # Just check if the data is in the same order, since we will not merge
+    # the data frames to save memory
+    stopifnot(all(unlist(x %>% map(function(y){all(y[,1] ==  x[[1]][,1])}) )))
+
+    # if hg38 we have 10 columns with probe metadata
+    # if hg19 we have 4 columns with probe metadata
+    idx.dnam <- grep("TCGA",colnames(x[[1]]))
+    df <- x %>%  map_df(idx.dnam)
+    colnames(df) <- x %>%  map_chr(.f = function(y) colnames(y)[idx.dnam])
+    df <- bind_cols(x[[1]][,1:(idx.dnam-1)],df)
+
 
     if (summarizedExperiment) {
       if(skip == 0) {
-        df <- makeSEfromDNAmethylation(df, probeInfo = as_data_frame(df)[,grep("TCGA",colnames(df),invert = TRUE)])
+        df <- makeSEfromDNAmethylation(
+          df,
+          probeInfo = data.frame(df)[,grep("TCGA",colnames(df),invert = TRUE)]
+        )
       } else {
         df <- makeSEfromDNAmethylation(df)
       }
@@ -743,49 +774,78 @@ colDataPrepareMMRF <- function(barcode){
 
 colDataPrepareTARGET <- function(barcode){
   message("Adding description to TARGET samples")
-  tissue.code <- c('01','02','03','04','05','06','07','08','09','10','11',
-                   '12','13','14','15','16','17','20','40','41','42','50','60','61','99')
+  tissue.code <- c(
+    '01',
+    '02',
+    '03',
+    '04',
+    '05',
+    '06',
+    '07',
+    '08',
+    '09',
+    '10',
+    '11',
+    '12',
+    '13',
+    '14',
+    '15',
+    '16',
+    '17',
+    '20',
+    '40',
+    '41',
+    '42',
+    '50',
+    '60',
+    '61',
+    '99'
+  )
 
-  definition <- c("Primary solid Tumor", # 01
-                  "Recurrent Solid Tumor", # 02
-                  "Primary Blood Derived Cancer - Peripheral Blood", # 03
-                  "Recurrent Blood Derived Cancer - Bone Marrow", # 04
-                  "Additional - New Primary", # 05
-                  "Metastatic", # 06
-                  "Additional Metastatic", # 07
-                  "Tissue disease-specific post-adjuvant therapy", # 08
-                  "Primary Blood Derived Cancer - Bone Marrow", # 09
-                  "Blood Derived Normal", # 10
-                  "Solid Tissue Normal",  # 11
-                  "Buccal Cell Normal",   # 12
-                  "EBV Immortalized Normal", # 13
-                  "Bone Marrow Normal", # 14
-                  "Fibroblasts from Bone Marrow Normal", # 15
-                  "Mononuclear Cells from Bone Marrow Normal", # 16
-                  "Lymphatic Tissue Normal (including centroblasts)", # 17
-                  "Control Analyte", # 20
-                  "Recurrent Blood Derived Cancer - Peripheral Blood", # 40
-                  "Blood Derived Cancer- Bone Marrow, Post-treatment", # 41
-                  "Blood Derived Cancer- Peripheral Blood, Post-treatment", # 42
-                  "Cell line from patient tumor", # 50
-                  "Xenograft from patient not grown as intermediate on plastic tissue culture dish", # 60
-                  "Xenograft grown in mice from established cell lines", #61
-                  "Granulocytes after a Ficoll separation") # 99
+  definition <- c(
+    "Primary solid Tumor", # 01
+    "Recurrent Solid Tumor", # 02
+    "Primary Blood Derived Cancer - Peripheral Blood", # 03
+    "Recurrent Blood Derived Cancer - Bone Marrow", # 04
+    "Additional - New Primary", # 05
+    "Metastatic", # 06
+    "Additional Metastatic", # 07
+    "Tissue disease-specific post-adjuvant therapy", # 08
+    "Primary Blood Derived Cancer - Bone Marrow", # 09
+    "Blood Derived Normal", # 10
+    "Solid Tissue Normal",  # 11
+    "Buccal Cell Normal",   # 12
+    "EBV Immortalized Normal", # 13
+    "Bone Marrow Normal", # 14
+    "Fibroblasts from Bone Marrow Normal", # 15
+    "Mononuclear Cells from Bone Marrow Normal", # 16
+    "Lymphatic Tissue Normal (including centroblasts)", # 17
+    "Control Analyte", # 20
+    "Recurrent Blood Derived Cancer - Peripheral Blood", # 40
+    "Blood Derived Cancer- Bone Marrow, Post-treatment", # 41
+    "Blood Derived Cancer- Peripheral Blood, Post-treatment", # 42
+    "Cell line from patient tumor", # 50
+    "Xenograft from patient not grown as intermediate on plastic tissue culture dish", # 60
+    "Xenograft grown in mice from established cell lines", #61
+    "Granulocytes after a Ficoll separation"
+  ) # 99
   aux <- DataFrame(tissue.code = tissue.code,definition)
 
   # in case multiple equal barcode
-  regex <- paste0("[:alnum:]{5}-[:alnum:]{2}-[:alnum:]{6}",
+  regex <- paste0("[:alnum:]{6}-[:alnum:]{2}-[:alnum:]{6}",
                   "-[:alnum:]{3}-[:alnum:]{3}")
   samples <- str_match(barcode,regex)[,1]
 
+  samples.df <- barcode %>% as.data.frame %>%  tidyr::separate(".",1:5 %>% as.character)
+
   ret <- DataFrame(
     barcode = barcode,
-    sample = substr(barcode, 1, 20),
-    patient = substr(barcode, 1, 16),
-    tumor.code = substr(barcode, 8, 9),
-    case.unique.id = substr(barcode, 11, 16),
-    tissue.code = substr(barcode, 18, 19),
-    nucleic.acid.code = substr(barcode, 24, 24)
+    tumor.code = samples.df[,2],
+    sample = paste0(samples.df[,1],"-",samples.df[,2],"-",samples.df[,3],"-",samples.df[,4]),
+    patient = paste0(samples.df[,1],"-",samples.df[,2],"-",samples.df[,3]),
+    case.unique.id = paste0(samples.df[,3]),
+    tissue.code = substr(samples.df[,4], 1, 2),
+    nucleic.acid.code = substr(samples.df[,5], 3, 3)
   )
 
   ret <- merge(ret,aux, by = "tissue.code", sort = FALSE)
@@ -906,18 +966,28 @@ colDataPrepare <- function(barcode){
   message("Starting to add information to samples")
   ret <- NULL
 
+
+
   if(all(grepl("TARGET",barcode))) ret <- colDataPrepareTARGET(barcode)
   if(all(grepl("TCGA",barcode))) ret <- colDataPrepareTCGA(barcode)
   if(all(grepl("MMRF",barcode))) ret <- colDataPrepareMMRF(barcode)
+
+  # How to deal with mixed samples "C3N-02003-01;C3N-02003-021" ?
+  # Check if this breaks the pacakge
+  if(any(grepl("C3N-|C3L-",barcode))) {
+    ret <- data.frame(sample =  sapply(barcode, function(x) stringr:::str_split(x,";") %>% unlist()) %>% unlist %>% unique,stringsAsFactors = FALSE)
+  }
   if(is.null(ret)) ret <- data.frame(sample = barcode %>% unique,stringsAsFactors = FALSE)
 
   message(" => Add clinical information to samples")
   # There is a limitation on the size of the string, so this step will be splited in cases of 100
   patient.info <- NULL
 
-  patient.info <- splitAPICall(FUN = getBarcodeInfo,
-                               step = 20,
-                               items = ret$sample)
+  patient.info <- splitAPICall(
+    FUN = getBarcodeInfo,
+    step = 10,
+    items = ret$sample
+  )
 
   if(!is.null(patient.info)) {
     ret$sample_submitter_id <- ret$sample %>% as.character()
@@ -947,10 +1017,26 @@ colDataPrepare <- function(barcode){
 
   # Put data in the right order
   ret <- ret[!duplicated(ret$bcr_patient_barcode),]
+
+
   idx <- sapply(substr(barcode,1,min(str_length(ret$bcr_patient_barcode))), function(x) {
     grep(x,ret$bcr_patient_barcode)
   })
 
+  # the code above does not work, since the projects have different string lengths
+  if(all(ret$project_id == "TARGET-ALL-P3")) {
+    idx <- sapply(gsub("-[[:alnum:]]{3}$","",barcode), function(x) {
+      grep(x,ret$bcr_patient_barcode)
+    })
+  }
+
+  if(any(ret$project_id == "CPTAC-3")) {
+    idx <- sapply(gsub("-[[:alnum:]]{3}$","",barcode), function(x) {
+      if(grepl(";",x = x)) x <- stringr::str_split(barcode[1],";")[[1]][1] # mixed samples
+      grep(x,ret$bcr_patient_barcode)
+    })
+  }
+
   ret <- ret[idx,]
 
   if("barcode" %in% colnames(ret)) ret$barcode <- barcode
@@ -1036,6 +1122,41 @@ readProteinExpression <- function(files,cases) {
   return(df)
 }
 
+readProteomeProfiling <- function(files,cases) {
+
+  list.of.protein.df <- plyr::alply(files,1, function(f) {
+    data <- readr::read_tsv(
+      file = f,
+      show_col_types = FALSE,
+      col_names = TRUE,
+      progress = FALSE
+    )
+    colnames(data)[ncol(data)] <- cases[which(f == files)]
+    data
+  }, .progress = "time")
+
+  # Just check if the data is in the same order, since we will not merge
+  # the data frames to save memory
+
+  df <- tryCatch({
+    stopifnot(all(unlist(list.of.protein.df %>% map(function(y){all(y[,5] ==  list.of.protein.df[[1]][,5])}) )))
+
+    # need to check if it works in all cases
+    # tested for HTSeq - FPKM-UQ and Counts only
+    bind_cols(list.of.protein.df[[1]][,1:5],list.of.protein.df %>%  map_df(6))
+  },error = function(e){
+    message("Some files have a  different number of proteins, we will introduce NA for the missing values")
+    plyr::join_all(dfs = list.of.protein.df ,type = "full",by = c("AGID","lab_id","catalog_number","set_id","peptide_target"))
+  })
+
+  if(!missing(cases))  colnames(df)[-c(1:5)] <- cases
+
+  return(df)
+}
+
+makeSEfromProteomeProfiling <- function(){
+
+}
 
 makeSEfromTranscriptomeProfilingSTAR <- function(data, cases, assay.list){
   # How many cases do we have?
@@ -1060,9 +1181,11 @@ makeSEfromTranscriptomeProfilingSTAR <- function(data, cases, assay.list){
 
   # Prepare data table
   # Remove the version from the ensembl gene id
-  assays <- list(data.matrix(data[,grep("unstranded",colnames(data))]),
-                 data.matrix(data[,grep("stranded_first",colnames(data))]),
-                 data.matrix(data[,grep("stranded_second",colnames(data))]))
+  assays <- list(
+    data.matrix(data[,grep("unstranded",colnames(data))]),
+    data.matrix(data[,grep("stranded_first",colnames(data))]),
+    data.matrix(data[,grep("stranded_second",colnames(data))])
+  )
   names(assays) <- c("unstranded","stranded_first","stranded_second")
   assays <- lapply(assays, function(x){
     colnames(x) <- NULL
@@ -1081,9 +1204,11 @@ makeSEfromTranscriptomeProfilingSTAR <- function(data, cases, assay.list){
     original_ensembl_gene_id = data$`#gene`
   )
   names(rowRanges) <- as.character(data$ensembl_gene_id)
-  rse <- SummarizedExperiment(assays = assays,
-                              rowRanges = rowRanges,
-                              colData = colData)
+  rse <- SummarizedExperiment(
+    assays = assays,
+    rowRanges = rowRanges,
+    colData = colData
+  )
   metadata(rse) <- metrics
   return(rse)
 }
@@ -1103,10 +1228,11 @@ makeSEfromTranscriptomeProfiling <- function(data, cases, assay.list){
   data$ensembl_gene_id <- as.character(gsub("\\.[0-9]*","",data$X1))
   data <- subset(data, grepl("ENSG", data$ensembl_gene_id))
   found.genes <- table(data$ensembl_gene_id %in% gene.location$ensembl_gene_id)
+
   if("FALSE" %in% names(found.genes))
     message(paste0("From the ", nrow(data), " genes we couldn't map ", found.genes[["FALSE"]]))
 
-  data <- merge(data, gene.location, by="ensembl_gene_id")
+  data <- merge(data, gene.location, by = "ensembl_gene_id")
 
   # Prepare data table
   # Remove the version from the ensembl gene id
@@ -1121,8 +1247,10 @@ makeSEfromTranscriptomeProfiling <- function(data, cases, assay.list){
   # Prepare rowRanges
   rowRanges <- GRanges(
     seqnames = paste0("chr", data$chromosome_name),
-    ranges = IRanges(start = data$start_position,
-                     end = data$end_position),
+    ranges = IRanges(
+      start = data$start_position,
+      end = data$end_position
+    ),
     strand = data$strand,
     ensembl_gene_id = data$ensembl_gene_id,
     external_gene_name = data$external_gene_name,
@@ -1139,10 +1267,16 @@ makeSEfromTranscriptomeProfiling <- function(data, cases, assay.list){
 }
 
 
-#' @importFrom purrr reduce
 #' @importFrom dplyr left_join
-#' @importFrom plyr alply
-readTranscriptomeProfiling <- function(files, data.type, workflow.type, cases,summarizedExperiment) {
+#' @importFrom plyr alply join_all
+#' @importFrom purrr map_dfc map map_df
+readTranscriptomeProfiling <- function(
+  files,
+  data.type,
+  workflow.type,
+  cases,
+  summarizedExperiment
+) {
 
   if(grepl("Gene Expression Quantification", data.type, ignore.case = TRUE)){
     # Status working for:
@@ -1152,22 +1286,38 @@ readTranscriptomeProfiling <- function(files, data.type, workflow.type, cases,su
     if(grepl("HTSeq",workflow.type)){
 
       x <- plyr::alply(files,1, function(f) {
-        readr::read_tsv(file = f,
-                        col_names = FALSE,
-                        progress = FALSE,
-                        col_types = c("cd"))
+        readr::read_tsv(
+          file = f,
+          col_names = FALSE,
+          progress = FALSE,
+          col_types = c("cd")
+        )
       }, .progress = "time")
-      df <- x %>% purrr::reduce(left_join, by = "X1")
+
+      # Just check if the data is in the same order, since we will not merge
+      # the data frames to save memory
+      stopifnot(all(unlist(x %>% map(function(y){all(y[,1] ==  x[[1]][,1])}) )))
+
+      # need to check if it works in all cases
+      # tested for HTSeq - FPKM-UQ and Counts only
+      df <- bind_cols(x[[1]][,1],x %>%  map_df(2))
       if(!missing(cases))  colnames(df)[-1] <- cases
       if(summarizedExperiment) df <- makeSEfromTranscriptomeProfiling(df,cases,workflow.type)
     } else  if(grepl("STAR",workflow.type)){
       x <- plyr::alply(files,1, function(f) {
-        readr::read_tsv(file = f,
-                        col_names = TRUE,
-                        progress = FALSE)
+        readr::read_tsv(
+          file = f,
+          col_names = TRUE,
+          progress = FALSE,
+          show_col_types = FALSE
+        )
       }, .progress = "time")
 
-      df <- x %>% purrr::reduce(left_join, by = "#gene")
+      suppressMessages({
+        df <- x %>%  map_dfc(.f = function(y) y[,2:4])
+        df <- bind_cols(x[[1]][,1],df)
+      })
+
       if(!missing(cases))  colnames(df)[-1] <- sapply(cases, function(x){stringr::str_c(c("unstranded_","stranded_first_", "stranded_second_"),x)}) %>% as.character()
       if(summarizedExperiment) df <- makeSEfromTranscriptomeProfilingSTAR(df,cases,workflow.type)
     }
@@ -1198,24 +1348,92 @@ readTranscriptomeProfiling <- function(files, data.type, workflow.type, cases,su
   return(df)
 }
 
-#' @importFrom purrr reduce
+readGeneLevelCopyNumber <- function(files, cases, summarizedExperiment = FALSE){
+  message("Reading Gene Level Copy Number files")
+  gistic.df <- NULL
+  gistic.list <- plyr::alply(files,1,.fun = function(file) {
+    #message("Reading file: ", file)
+    data <- read_tsv(
+      file = file,
+      col_names = TRUE,
+      progress = TRUE,
+      col_types = readr::cols()
+    )
+    colnames(data)[-c(1:5)] <- paste0(cases[match(file,files)],"_",  colnames(data)[-c(1:5)])
+
+    return(data)
+  })
+
+  # Check if the data is in the same order
+  stopifnot(all(unlist(gistic.list %>% map(function(y){all(y[,1:5] ==  gistic.list[[1]][,1:5])}) )))
+
+  # need to check if it works in all cases
+  # tested for HTSeq - FPKM-UQ and Counts only
+  df <- bind_cols(
+    gistic.list[[1]][,1:5], # gene info
+    gistic.list %>%  map_dfc(.f = function(x) x[,6:8]) # copy number, min,max
+  )
+
+  if(summarizedExperiment) {
+    se <- makeSEfromGeneLevelCopyNumber(df, cases)
+    return(se)
+  }
+  return(df)
+}
+
+makeSEfromGeneLevelCopyNumber <- function(df, cases){
+  message("Creating a SummarizedExperiment object")
+  rowRanges <- GRanges(
+    seqnames = df$chromosome,
+    ranges = IRanges(start = df$start, end = df$end),
+    gene_id = df$gene_id,
+    gene_name = df$gene_name
+  )
+
+  names(rowRanges) <- as.character(df$gene_id)
+  colData <-  colDataPrepare(cases)
+
+  # We have three data columns for each files
+  assays <- lapply(
+    c("[^max|min]_copy_number","min_copy_number", "max_copy_number"),
+    function(x){
+      ret <- data.matrix(subset(df,select = grep(x,colnames(df))))
+      colnames(ret) <- cases
+      rownames(ret) <- NULL
+      ret
+    })
+  names(assays) <-   c("copy_number","min_copy_number", "max_copy_number")
+
+  rse <- SummarizedExperiment(assays = assays, rowRanges = rowRanges, colData = colData)
+  return(rse)
+}
+
+
 readGISTIC <- function(files, cases){
   message("Reading GISTIC file")
   gistic.df <- NULL
   gistic.list <- plyr::alply(files,1,.fun = function(file) {
     message("Reading file: ", file)
-    data <- read_tsv(file = file, col_names = TRUE, progress = TRUE,col_types = readr::cols())
+    data <- read_tsv(
+      file = file,
+      col_names = TRUE,
+      progress = TRUE,
+      col_types = readr::cols()
+    )
 
     aliquot <- colnames(data)[-c(1:3)]
-    info <- splitAPICall(FUN = getBarcodefromAliquot,
-                         step = 20,
-                         items = aliquot)
+    info <- splitAPICall(
+      FUN = getBarcodefromAliquot,
+      step = 20,
+      items = aliquot
+    )
 
     barcode <- as.character(info$submitter_id)[match(aliquot,as.character(info$aliquot_id))]
     colnames(data)[-c(1:3)] <- barcode
     return(data)
   })
-  gistic.df <- gistic.list %>% purrr::reduce(dplyr::full_join, by = c("Gene Symbol","Gene ID","Cytoband"))
+  gistic.df <- gistic.list %>%
+    join_all(by =  c("Gene Symbol","Gene ID","Cytoband"), type='full')
 
   return(gistic.df)
 }
