@@ -200,7 +200,7 @@ GDCquery <- function(
         }
         if(missing(platform)) {
             platform <- NA
-        } else if(platform == FALSE) {
+        } else if(any(platform == FALSE)) {
             platform <- NA
         }
         if(missing(file.type)) {
@@ -240,16 +240,18 @@ GDCquery <- function(
     results <- NULL
     print.header("Accessing GDC. This might take a while...","subsection")
     for(proj in project){
-        url <- getGDCquery(project = proj,
-                           data.category = data.category,
-                           data.type = data.type,
-                           legacy = legacy,
-                           workflow.type = workflow.type,
-                           platform = platform,
-                           file.type = file.type,
-                           files.access = access,
-                           experimental.strategy = experimental.strategy,
-                           sample.type = sample.type)
+        url <- getGDCquery(
+            project = proj,
+            data.category = data.category,
+            data.type = data.type,
+            legacy = legacy,
+            workflow.type = workflow.type,
+            platform = platform,
+            file.type = file.type,
+            files.access = access,
+            experimental.strategy = experimental.strategy,
+            sample.type = sample.type
+        )
         message("ooo Project: ", proj)
         json  <- tryCatch(
             getURL(url,fromJSON,timeout(600),simplifyDataFrame = TRUE),
@@ -260,16 +262,18 @@ GDCquery <- function(
             }
         )
         if(json$data$pagination$count == 0) {
-            url <- getGDCquery(project = proj,
-                               data.category = data.category,
-                               data.type = data.type,
-                               legacy = legacy,
-                               workflow.type = NA,
-                               platform = NA,
-                               file.type = file.type,
-                               experimental.strategy = experimental.strategy,
-                               files.access = access,
-                               sample.type = sample.type)
+            url <- getGDCquery(
+                project = proj,
+                data.category = data.category,
+                data.type = data.type,
+                legacy = legacy,
+                workflow.type = NA,
+                platform = NA,
+                file.type = file.type,
+                experimental.strategy = experimental.strategy,
+                files.access = access,
+                sample.type = sample.type
+            )
             json  <- tryCatch(
                 getURL(url,fromJSON,timeout(600),simplifyDataFrame = TRUE),
                 error = function(e) {
@@ -284,16 +288,17 @@ GDCquery <- function(
         json$data$hits$acl <- NULL
         json$data$hits$project <- proj
 
-        if("archive" %in% colnames(json$data$hits)){
-            if(is.data.frame(json$data$hits$archive)){
+        if ("archive" %in% colnames(json$data$hits)) {
+            if (is.data.frame(json$data$hits$archive)) {
                 archive <- json$data$hits$archive
                 colnames(archive)[1:ncol(archive)] <- paste0("archive_", colnames(archive)[1:ncol(archive)])
                 json$data$hits$archive <- NULL
                 json$data$hits <- cbind(json$data$hits, archive)
             }
         }
-        if("analysis" %in% colnames(json$data$hits)){
-            if(is.data.frame(json$data$hits$analysis)){
+
+        if ("analysis" %in% colnames(json$data$hits)){
+            if (is.data.frame(json$data$hits$analysis)){
                 analysis <- json$data$hits$analysis
                 # Columns
                 # "analysis_id"
@@ -432,13 +437,15 @@ GDCquery <- function(
     # 1) Normally for each sample we will have only single information
     # however the mutation call uses both normal and tumor which are both
     # reported by the API
-    if(!data.category %in% c("Clinical",
-                             "Copy Number Variation",
-                             "Biospecimen",
-                             "Other",
-                             "Simple Nucleotide Variation",
-                             "Simple nucleotide variation",
-                             "Protein expression")){
+    if(!data.category %in% c(
+        "Clinical",
+        "Copy Number Variation",
+        "Biospecimen",
+        "Other",
+        "Simple Nucleotide Variation",
+        "Simple nucleotide variation",
+        "Protein expression")
+    ){
 
         # we also need to deal with pooled samples (mixed from different patients)
         # example CPT0000870008
@@ -449,7 +456,7 @@ GDCquery <- function(
                                    summarize(
                                        x$samples[[1]],
                                        submitter_id = paste(submitter_id,collapse = ";"),
-                                       is_ffpe = any(is_ffpe),
+                                       is_ffpe = ifelse("is_ffpe" %in% colnames(x),any(is_ffpe),NA),
                                        sample_type =  paste(sample_type,collapse = ";"),
                                        aliquot.submiter.id = x$samples[[1]]$portions[[1]]$analytes[[1]]$aliquots[[1]]$submitter_id)
                                }) %>% as.data.frame
@@ -459,7 +466,7 @@ GDCquery <- function(
                                    summarize(
                                        x$samples[[1]],
                                        submitter_id = paste(submitter_id,collapse = ";"),
-                                       is_ffpe = any(is_ffpe),
+                                       is_ffpe = ifelse("is_ffpe" %in% colnames(x),any(is_ffpe),NA),
                                        sample_type =  paste(sample_type,collapse = ";"))
                                }) %>% as.data.frame
 
@@ -468,11 +475,12 @@ GDCquery <- function(
         results$is_ffpe <- aux$is_ffpe %>% as.logical
 
         if("submitter_id" %in% names(unlist(results$cases))) {
-            results$cases.submitter_id <- plyr::laply(results$cases,
-                                                      function(x) {
-                                                          paste(x$submitter_id,collapse = ";")
-                                                      })  %>%
-                as.character()
+            results$cases.submitter_id <- plyr::laply(
+                results$cases,
+                function(x) {
+                    paste(x$submitter_id,collapse = ";")
+                }
+            )  %>% as.character()
         }
         # ORGANOID-PANCREATIC does not have aliquots
         if("aliquot.submiter.id" %in% colnames(aux)){
@@ -883,7 +891,8 @@ getMC3MAF <- function(){
     fpath <- "https://api.gdc.cancer.gov/data/1c8cfe5f-e52d-41ba-94da-f15ea1337efc"
     if(is.windows()) mode <- "wb" else  mode <- "w"
     message(rep("-",100))
-    message("o Starting to download Publi MAF from GDC")
+    options(timeout = 1000) # set 1000 second to download the file, default is 60 seconds
+    message("o Starting to download Public MAF from GDC")
     message("o More information at: https://gdc.cancer.gov/about-data/publications/mc3-2017")
     message("o Please, cite: Cell Systems. Volume 6 Issue 3: p271-281.e7, 28 March 2018 10.1016/j.cels.2018.03.002")
     if(!file.exists(gsub("\\.gz", "", fout))){
@@ -895,15 +904,17 @@ getMC3MAF <- function(){
     maf <- readr::read_tsv(gsub("\\.gz", "", fout),progress = TRUE, col_types = readr::cols())
     message("o Adding project_id information")
     project <- grep("TCGA",sort(getGDCprojects()$project_id),value = TRUE)
-    df <- plyr::adply(project,
-                      .margins = 1,
-                      .fun = function(proj) {
-                          samples <- getSubmitterID(proj)
-                          return(data.frame(proj,samples))
-                      }
+    df <- plyr::adply(
+        project,
+        .margins = 1,
+        .fun = function(proj) {
+            samples <- getSubmitterID(proj)
+            return(data.frame(proj,samples))
+        }
     )
     maf$project_id <- df$proj[match(substr(maf$Tumor_Sample_Barcode,1,12),df$samples)] %>% as.character
     message(rep("-",100))
+    return(maf)
 }
 
 
@@ -911,7 +922,7 @@ getMC3MAF <- function(){
 #' @description
 #'   TCGArecount2_query queries and downloads data produced by the Recount2 project. User can specify which project and which tissue to query
 #' @param project is a string denoting which project the user wants. Options are "tcga" and "gtex"
-#' @param tissue a vector of tissue(s) to download. Options are "adipose tissue", "adrenal", "gland", "bladder","blood", "blood vessel", "bone marrow", "brain", "breast","cervix uteri", "colon", "esophagus", "fallopian tube","heart", "kidney", "liver", "lung", "muscle", "nerve", "ovary","pancreas", "pituitary", "prostate", "salivary", "gland", "skin", "small intestine", "spleen", "stomach", "testis", "thyroid", "uterus", "vagina"
+#' @param tissue a vector of tissue(s) to download. Options are "adipose tissue", "adrenal gland", "bladder","blood", "blood vessel", "bone marrow", "brain", "breast","cervix uteri", "colon", "esophagus", "fallopian tube","heart", "kidney", "liver", "lung", "muscle", "nerve", "ovary","pancreas", "pituitary", "prostate", "salivary gland", "skin", "small intestine", "spleen", "stomach", "testis", "thyroid", "uterus", "vagina"
 #' @export
 #' @examples
 #' \dontrun{
@@ -982,34 +993,34 @@ TCGAquery_recount2<-function(project, tissue=c()){
         "uterus")
 
 
-    tissue<-paste(unlist(strsplit(tissue, " ")), collapse="_")
+    tissue<-unlist(lapply(strsplit(tissue, " "), function(x) paste(x, collapse = "_")))
     Res<-list()
 
     if(tolower(project)=="gtex"){
         for(t_i in tissue){
-            if(tissue%in%tissuesGTEx){
+            if(t_i%in%tissuesGTEx){
                 con<-"http://duffel.rail.bio/recount/v2/SRP012682/rse_gene_"
-                con<-paste0(con,tissue,".Rdata")
+                con<-paste0(con,t_i,".Rdata")
 
-                message(paste0("downloading Range Summarized Experiment for: ", tissue))
+                message(paste0("downloading Range Summarized Experiment for: ", t_i))
                 load(url(con))
                 Res[[paste0(project,"_", t_i)]]<-rse_gene
             }
-            else stop(paste0(tissue, " is not an available tissue on Recount2"))
+            else stop(paste0(t_i, " is not an available tissue on Recount2"))
         }
         return(Res)
     }
     else if(tolower(project)=="tcga"){
         for(t_i in tissue){
-            if(tissue%in%tissuesTCGA){
+            if(t_i%in%tissuesTCGA){
                 con<-"http://duffel.rail.bio/recount/v2/TCGA/rse_gene_"
-                con<-paste0(con,tissue,".Rdata")
-                message(paste0("downloading Range Summarized Experiment for: ", tissue))
+                con<-paste0(con,t_i,".Rdata")
+                message(paste0("downloading Range Summarized Experiment for: ", t_i))
                 load(url(con))
                 Res[[paste0(project,"_", t_i)]]<-rse_gene
 
             }
-            else stop(paste0(tissue, " is not an available tissue on Recount2"))
+            else stop(paste0(t_i, " is not an available tissue on Recount2"))
         }
         return(Res)
     }
